/*
# The Sample code for test the data of Analogue_Test and SHT1X Module 
 
 # Editor : Phoebe
 # Date   : 2012.10.25
 # Ver    : 0.2
 # Product: Analogue_Test and SHT1X Module
 # SKU    : 
 
 # Description:     
 # Read the Analog value and the data of humidity & temperature 
 
 # Hardwares:
 1. Arduino UNO
 2. IO Expansion Shield V5
 3. Analogue_Test and SHT1X Module 
 
 # Interface: RS485
 # Note: Connect the Analogue_Test and SHT1X Module with IO Expansion Shield V5 through RS485
  Set the address of the module in manual,range from 0x02 to 0x7F,take effect after 30 seconds
 */

#define uint    unsigned  int
#define uchar   unsigned  char
#define ulong   unsigned  long
#define addr  0x02     //set address of the device for 0x02
uchar cmd[50];
uchar receive_ACK[100];
int EN=2;

#if defined(ARDUINO) && ARDUINO >= 100
#include "Arduino.h"
#define printByte(args) Serial.write(args)
#define printlnByte(args)  Serial.write(args),Serial.println()
#else
#include "WProgram.h"
#define printByte(args) Serial.print(args,BYTE)
#define printlnByte(args)  Serial.println(args,BYTE)
#endif

void setup(){
  Serial.begin(9600);
  pinMode(2,OUTPUT);// TTL -> RS485 chip driver pin
}

void loop(){  
  static ulong timepoint=0;
  if(millis()-timepoint> 500){    
    read_command();
    timepoint=millis();
  }
  if (Serial.available() > 0) data_return();  
  
  delay(1000);

}

/************************Send command to Analogue_Test and SHT1X Module*************************/
void read_command()
{
  int i;
  char sum_cmd = 0;
  digitalWrite(EN,HIGH);// Turn the drvier pin to HIGH -> Turn on code transmitting mode for the RS485 interface
  // Turn the driver pin to LOW  -> Turn on reading mode for the RS485 interface
  delay(10);
  cmd[0] = 0x55;
  cmd[1] = 0xaa;
  cmd[2] = addr;
  cmd[3] = 0x00;
  cmd[4] = 0x21;   
  for(i = 0;i < 5;i++){
    sum_cmd += cmd[i];
  }   
  cmd[5] = sum_cmd;   
  for(i = 0;i < 6;i++){
    printByte(cmd[i]);// command send to device
    #if defined(ARDUINO) && ARDUINO >= 100
    Serial.flush();// complete the transmission of outgoing serial data 
    #endif
    delay(10);
  }
  digitalWrite(EN,LOW);
}
/************Feedback data of the Analog value and humidity & temperature ************/\

void data_return()
{
  digitalWrite(EN,LOW);// Turn the driver pin to LOW  -> Turn on reading mode for the RS485 interface
  delay(10);
  for(int j = 0; j < 26; j++)                                         
  {
    if (Serial.available() > 0)
    {
      receive_ACK[j]= Serial.read();
      delay(20);
      Serial.print( receive_ACK[j],HEX); // return command 
      Serial.print( " "); 
      if(receive_ACK[0] != 0x55 || receive_ACK[1] != 0xAA && j > 1) break;//detect the head byte of feedback datas
    }
  }
  Serial.println(" ");  
  show_0x21_command();//Get datas from the module
  digitalWrite(EN,HIGH);
} 

void show_0x21_command(void)
{
  sht1x_data();
  Analog_test_data();

} 

/************Deal with datas from Sht1x humidity & temperature sensor************/

void sht1x_data()
{
  uint humidity;
  uint temperature;
  humidity =  receive_ACK[7] * 256 + receive_ACK[8];
  temperature= receive_ACK[9] * 256 + receive_ACK[10];
  Serial.print("H:");
  Serial.print(humidity/10,DEC); 
  Serial.print("  ");
  Serial.print("T:");
  Serial.println(temperature/10,DEC);
}

/********************Deal with datas from 6 Analog Sensors****************/
void Analog_test_data()
{
  char register_addr;
  uint  Analog_data; 
  register_addr=13;
  Serial.print("Analog Value:");
  for(int n=1;n< 7;n++){
    Analog_data =receive_ACK[register_addr] *256 + receive_ACK[register_addr+1];
    register_addr=register_addr+2;
    Serial.print(Analog_data,DEC);
    Serial.print(" ");
  }
  Serial.println(" ");
  delay(1000);
}



